@@ -5,21 +5,17 @@
 
 data(display)
 
-if.R(s={old.omd <- par(omd=c(.08,1,.05,1))},
-     r={})
 interaction2wt(time ~ panel + emergenc, data=display,
-               par.strip.text=list(cex=if.R(s=1, r=1.1)),
+               par.strip.text=list(cex=1.1),
                main.cex=1.6,
                scales=list(x=list(cex=.9), y=list(cex=.9, alternating=FALSE)))
 ## export.eps(hh("tway/figure/display.eps"))
-if.R(s=par(old.omd), r={})
 
 
 
 ## display$panel has polynomial contrasts as part of "position" for graphing.
 ## glht in R needs treatment contrasts.
-if.R(r=contrasts(display$panel) <- contr.treatment(3),
-     s={})
+contrasts(display$panel) <- contr.treatment(3)
 
 
 ## emergenc fixed
@@ -31,66 +27,39 @@ displayr.aov <- aov(time ~  panel + Error(emergenc + panel:emergenc),
                     data=display)
 summary(displayr.aov)
 
-if.R(s={
-  ## multiple comparisons, Tukey method
-  tmp <- multicomp(displayf.aov, "panel", plot=TRUE)
-  tmp
-},r={
-  tmp <- glht(displayf.aov, linfct=mcp(
-                              panel="Tukey",
-                              `interaction_average` = TRUE,
-                              `covariate_average` = TRUE))
-  plot(tmp)
-  confint(tmp)
-})
+## multiple comparisons, Tukey method
+tmp <- glht(displayf.aov, linfct=mcp(
+                            panel="Tukey",
+                            `interaction_average` = TRUE,
+                            `covariate_average` = TRUE))
+plot(tmp)
+confint(tmp)
 ## export.eps(hh("tway/figure/display-mcdiff.eps"))
 
-if.R(s={
-  tmp <- multicomp(displayf.aov, "panel", plot=TRUE, comp="none")
-  tmp
-  ## export.eps(hh("tway/figure/display-mcmean.eps"))
-}, r={
-  tmp <- glht(displayf.aov, linfct=mcp(panel="Means",
-                              `interaction_average` = TRUE,
-                              `covariate_average` = TRUE))
-  plot(tmp)
-  confint(tmp)
-})
+tmp <- glht(displayf.aov, linfct=mcp(panel="Means",
+                            `interaction_average` = TRUE,
+                            `covariate_average` = TRUE))
+plot(tmp)
+confint(tmp)
+## export.eps(hh("tway/figure/display-mcmean.eps"))
 
 ## multiple comparisons, mmc plot, Tukey method
-if.R(s={
-  displayf.mmc <- multicomp.mmc(displayf.aov, "panel", plot=TRUE)
-  displayf.mmc
-},r={
-  displayf.mmc <- mmc(displayf.aov, focus="panel")
-  plot(displayf.mmc, x.offset=1.5)
-  displayf.mmc
-})
+displayf.mmc <- mmc(displayf.aov, focus="panel")
+plot(displayf.mmc, x.offset=1.5)
+displayf.mmc
 ## export.eps(hh("tway/figure/display-mmcdiff.eps"))
 
 ## compare with SAS display
-if.R(s={
-  tmp <- multicomp(displayf.aov, "panel", plot=FALSE)
-  print(qtukey(.95, 3, 12)/sqrt(2))##
-  print(tmp$crit.point)            ## S-Plus critical value
-  print(tmp$crit.point * sqrt(2))  ## SAS: Critical Value of Studentized Range
-},r={
-  tmp <- glht(displayf.aov, linfct=mcp(
-                              panel="Tukey",
-                              `interaction_average` = TRUE,
-                              `covariate_average` = TRUE))
-  print(qtukey(.95, 3, 12)/sqrt(2))            ##
-  print(attr(confint(tmp)$confint, "calpha"))  ## R critical value
-  print(attr(confint(tmp)$confint, "calpha") * sqrt(2))  ## SAS: Critical Value of Studentized Range
-})
+tmp <- glht(displayf.aov, linfct=mcp(
+                            panel="Tukey",
+                            `interaction_average` = TRUE,
+                            `covariate_average` = TRUE))
+print(qtukey(.95, 3, 12)/sqrt(2))            ##
+print(attr(confint(tmp)$confint, "calpha"))  ## R critical value
+print(attr(confint(tmp)$confint, "calpha") * sqrt(2))  ## SAS: Critical Value of Studentized Range
 
-if.R(s={
-    ms.res <- summary(displayf.aov)["     Residuals","Mean Sq"]
-    sqrt(2*ms.res/8) * tmp$crit.point  ## minimum significant difference
-},r={
-    ms.res <- summary(displayf.aov)[[1]]["Residuals","Mean Sq"]
-    sqrt(2*ms.res/8) * attr(confint(tmp)$confint, "calpha")  ## minimum significant difference
-})
+ms.res <- summary(displayf.aov)[[1]]["Residuals","Mean Sq"]
+sqrt(2*ms.res/8) * attr(confint(tmp)$confint, "calpha")  ## minimum significant difference
 ## there are 8 observations in each of the three groups
 
 
@@ -109,7 +78,6 @@ rhiz.clover <- rhiz.clover ## local copy
 
 
 ## rhiz-bwplot.ti.r    # rhiz, Fig 11.2 11.3 11.4 ## preferred
-if.R(r={
 ## vertical boxplots conditioned on combination
 ## our preference
 
@@ -122,7 +90,7 @@ bwplot(Npg ~ strain | comb, data=rhiz.alfalfa,
 print(position = c(0, 0, 1, .47), more = TRUE,  # bottom
 bwplot(Npg ~ strain | comb, data=rhiz.clover,
          main="clover", layout=c(2,1),
-         par.srip.text=list(cex=.9),
+         par.strip.text=list(cex=.9),
          scales=list(cex=.75))
 )
 print(position=c(0, .95, 1, 1), more=FALSE,
@@ -177,58 +145,6 @@ print(position=c(0, .95, 1, 1), more=FALSE,
              par.settings = list(axis.line = list(col = "transparent")))
 )
 ## export.eps(hh("tway/figure/rhw.ti.eps"))
-}, s={
-## rhiz-bwplot.ti.s
-## vertical boxplots conditioned on combination
-## our preference
-
-print(split = c(1,2,1,2), more = TRUE,  # top
-t(bwplot(strain ~ Npg | comb, data=rhiz.alfalfa,
-         main="alfalfa", layout=c(2,1),
-         par.strip.text=list(cex=.9),
-         scales=list(cex=.75))
-))
-print(split = c(1,1,1,2), more = FALSE,  # bottom
-t(bwplot(strain ~ Npg | comb, data=rhiz.clover,
-         main="clover", layout=c(2,1),
-         par.strip.text=list(cex=.9),
-         scales=list(cex=.75))
-))
-mtext("Nitrogen per gram", outer=TRUE, side=3)
-## export.eps(hh("tway/figure/rhnpg.ti.eps"))
-
-
-print(split = c(1,2,1,2), more = TRUE,  # top
-t(bwplot(strain ~ nitro | comb, data=rhiz.alfalfa,
-         main="alfalfa", layout=c(2,1),
-         par.strip.text=list(cex=.9),
-         scales=list(cex=.75))
-))
-print(split = c(1,1,1,2), more = FALSE,  # bottom
-t(bwplot(strain ~ nitro | comb, data=rhiz.clover,
-         main="clover", layout=c(2,1),
-         par.strip.text=list(cex=.9),
-         scales=list(cex=.75))
-))
-mtext("Nitrogen", outer=TRUE, side=3)
-## export.eps(hh("tway/figure/rhn.ti.eps"))
-
-
-print(split = c(1,2,1,2), more = TRUE,  # top
-t(bwplot(strain ~ weight | comb, data=rhiz.alfalfa,
-         main="alfalfa", layout=c(2,1),
-         par.strip.text=list(cex=.9),
-         scales=list(cex=.75))
-))
-print(split = c(1,1,1,2), more = FALSE,  # bottom
-t(bwplot(strain ~ weight | comb, data=rhiz.clover,
-         main="clover", layout=c(2,1),
-         par.strip.text=list(cex=.9),
-         scales=list(cex=.75))
-))
-mtext("Weight", outer=TRUE, side=3)
-## export.eps(hh("tway/figure/rhw.ti.eps"))
-})
 
 ## The HH text (page 357) suggests three alternate arrangements for
 ## the boxplots, and references three files for the details.
@@ -253,26 +169,20 @@ mtext("Weight", outer=TRUE, side=3)
 ## rhiz-alf-aov.s      # rhiz, Fig 11.5 11.6 Table 11.5
 
 rhiz.alfalfa.aov <- aov(Npg ~ strain * comb, data=rhiz.alfalfa)
-summary(rhiz.alfalfa.aov) 
+summary(rhiz.alfalfa.aov)
 
 alf.means <- model.tables(rhiz.alfalfa.aov, type="means", se=TRUE)
 alf.means$tables$strain
 alf.means$n["strain"]
 alf.means$se$strain
 
-if.R(r={
-  alfalfa.mca <- glht(rhiz.alfalfa.aov, linfct=mcp(strain="Tukey",
-                              `interaction_average` = TRUE,
-                              `covariate_average` = TRUE))
-  old.omd <- par(omd=c(.15,1, 0,1))
-  plot(alfalfa.mca)
-  par(old.omd)
-  print(confint(alfalfa.mca))
-}, s={
-  alfalfa.mca <- multicomp.reverse(multicomp(rhiz.alfalfa.aov, focus="strain"))
-  plot(alfalfa.mca)
-  print(alfalfa.mca)
-})
+alfalfa.mca <- glht(rhiz.alfalfa.aov, linfct=mcp(strain="Tukey",
+                                        `interaction_average` = TRUE,
+                                        `covariate_average` = TRUE))
+old.omd <- par(omd=c(.15,1, 0,1))
+plot(alfalfa.mca)
+par(old.omd)
+print(confint(alfalfa.mca))
 ## export.eps(hh("tway/figure/alfmc.ps"))
 
 
@@ -288,7 +198,7 @@ axis(3)
 mtext("Npg", 3, line=3)
 lines(x=c(29.7,31.5), y=c(.95,.95))
 lines(x=c(30.5,32.5), y=c(.90,.90))
-strain.labels <- paste(dimnames(alf.means$tables$strain)[[if.R(s=2,r=1)]],
+strain.labels <- paste(dimnames(alf.means$tables$strain)[[1]],
                        format(alf.means$tables$strain, digits=6),
                        sep=": ")
 
@@ -305,7 +215,7 @@ par(fin=old.fin)
 
 ## rhiz-clov-aov.s     # rhiz, Fig 11.7 Table 11.6 11.7 11.8 11.9
 rhiz.clover.aov <- aov(Npg ~ strain * comb, data=rhiz.clover)
-summary(rhiz.clover.aov) 
+summary(rhiz.clover.aov)
 
 clov.means <- model.tables(rhiz.clover.aov, type="means", se=TRUE)
 
@@ -334,17 +244,10 @@ rhiz.clover.nest.aov <- aov(Npg ~ comb/strain, data=rhiz.clover)
 summary(rhiz.clover.nest.aov)
 
 names(coef(rhiz.clover.nest.aov))
-if.R(s=
-summary(rhiz.clover.nest.aov,
-        split=list("strain %in% comb"=
-          list(clover=c(1,3,5,7,9),
-               "clover+alfalfa"=c(2,4,6,8,10))))
-,r=
 summary(rhiz.clover.nest.aov,
         split=list("comb:strain"=
           list(clover=c(1,3,5,7,9),
                "clover+alfalfa"=c(2,4,6,8,10))))
-)
 
 ## Look at the contrasts, their generated dummy variables,
 ## and their regression coefficients.
@@ -367,7 +270,6 @@ cnxb
 
 
 ## rhiz-alf-mmc.s
-if.R(r={
 old.omd <- par(omd=c(0,.85 ,0,1))
 ## the above value of omd sets fig to the invalid value
 ## > par()$fig
@@ -400,41 +302,10 @@ plotMatchMMC(alf.mmc$lmat, col.signif="blue")
 print(alf.mmc)
 ## export.eps(hh("tway/figure/alfalfa.lmat.mmc-tiebreak.eps"))
 par(old.omd)
-}, s={
-old.omd <- par(omd=c(0,.85 ,0,1))
-alf.mmc <- multicomp.mmc(rhiz.alfalfa.aov, focus="strain", x.offset=.3, ry=c(29.5, 33))
-## export.eps(hh("tway/figure/alfalfa.mmc.eps"))
-## this plot is hard to read, we need to break the ties and retain the order
-plotMatchMMC(alf.mmc$mca)
-print(alf.mmc)
-## export.eps(hh("tway/figure/alfalfa.mmc-tiebreak.eps"))
-
-## construct an orthogonal set of interpretable contrasts
-zapsmall(alf.mmc$none$lmat[2:7,]) ## strain rows
-##                              c 15 12  1 10  7
-alf.comp <- cbind("1,7,10-c"=c(-3, 0, 0, 1, 1, 1),
-                  "1,10-7"  =c( 0, 0, 0, 1, 1,-2),
-                  "1-10"    =c( 0, 0, 0, 1,-1, 0),
-                  "15-12"   =c( 0, 1,-1, 0, 0, 0),
-            "1,7,10,c-12,15"=c( 1,-2,-2, 1, 1, 1))
-
-alf.lmat <- alf.mmc$none$lmat %*% alf.comp
-zapsmall(alf.lmat)[2:7,]
-
-alf.mmc <- multicomp.mmc(rhiz.alfalfa.aov, focus="strain", x.offset=.3, ry=c(29.5, 33),
-                         lmat=alf.lmat)
-## export.eps(hh("tway/figure/alfalfa.lmat.mmc.eps"))
-## this plot is hard to read, we need to break the ties and retain the order
-plotMatchMMC(alf.mmc$lmat, col.signif="blue")
-print(alf.mmc)
-## export.eps(hh("tway/figure/alfalfa.lmat.mmc-tiebreak.eps"))
-par(old.omd)
-})
 
 
 ## rhiz-clov-mmc.s
 
-if.R(r={
 ## rhiz.clover.nest.aov <- aov(Npg ~ comb/strain, data=rhiz.clover)
 summary(rhiz.clover.nest.aov)
 summary(rhiz.clover.nest.aov,
@@ -445,14 +316,14 @@ model.tables(rhiz.clover.nest.aov, type="means", se=TRUE)
 ## This gives the anova table we are interested,
 ## R glht won't work with a nested model.
 
-#####  see HH-R.package/HH/demo/MMC.WoodEnergy.R   ##### 
+#####  see HH-R.package/HH/demo/MMC.WoodEnergy.R   #####
 #####  see also 8004.s09/0212/ironpot.s            #####
 #####  hh/dsgn/code/filmcoat3.s                    #####
 #####  hh/dsgntwo/answer/bean4.s                   #####
 
 ## use the crossed model from rhiz-clov-aov.s with the adjust argument
 rhiz.clover.aov <- aov(Npg ~ strain * comb, data=rhiz.clover)
-summary(rhiz.clover.aov) 
+summary(rhiz.clover.aov)
 model.tables(rhiz.clover.aov, type="means", se=TRUE)
 
 ## compare simple effects with clover+alfalfa to simple effects with clover
@@ -537,99 +408,6 @@ clover.str.clov.mmc$clover <- mmc(rhiz.clover.comb.aov$clover,
                                   focus.lmat=clover.comp)
 plot(clover.str.clov.mmc$clover, ry=c(16,40), main=i, main2="")
 plotMatchMMC(clover.str.clov.mmc$clover$lmat, col.signif=8, lty.signif=1, main=i)
-}, s={
-## rhiz.clover.nest.aov <- aov(Npg ~ comb/strain, data=rhiz.clover)
-summary(rhiz.clover.nest.aov)
-summary(rhiz.clover.nest.aov,
-        split=list("strain %in% comb"=
-          list(clover=c(1,3,5,7,9),
-               "clover+alfalfa"=c(2,4,6,8,10))))
-model.tables(rhiz.clover.nest.aov, type="means", se=TRUE)
-## This gives the anova table we are interested,
-## S-Plus multicomp won't work with a nested model.
-
-
-
-## use the crossed model from rhiz-clov-aov.s with the adjust argument
-rhiz.clover.aov <- aov(Npg ~ strain * comb, data=rhiz.clover)
-summary(rhiz.clover.aov) 
-model.tables(rhiz.clover.aov, type="means", se=TRUE)
-
-old.omd <- par(omd=c(0,.8,0,1))
-## compare simple effects with clover+alfalfa to simple effects with clover
-## force these graphs to have the same xlim and ylim as the previous graphs
-## simple effects with clover
-clover.str.clov.mmc <-
-multicomp.mmc(rhiz.clover.aov, focus="strain",
-              adjust=list(comb="clover"),
-              method="Tukey",
-              crit.point=qtukey(1-.05/2, 6, 48)/sqrt(2),
-              ry=c(19,38),
-              plot=FALSE)
-clover.str.clov.mmc <-
-  multicomp.label.change(clover.str.clov.mmc, "adj1", "clov")
-for (i in 1:2)
-  clover.str.clov.mmc[[i]]$method <- "Tukey"
-plot(clover.str.clov.mmc)
-## mca only, no lmat
-## export.eps(h2("mmc/figure/clover.str.clov.mmc.eps"))
-## export.eps(h2("mmc/figure/clover.str.clov.mmc-color.eps"))
-plotMatchMMC(clover.str.clov.mmc$mca, col.signif=8, lty.signif=1)
-## export.eps(h2("mmc/figure/clover.str.clov.mca.eps"))
-
-## construct an orthogonal basis set of contrasts
-
-zapsmall(clover.str.clov.mmc$none$lmat[2:7,]) ## strain rows
-##                               5  1  c  7 13  4
-clover.comp <- cbind("5-rest"=c( 5,-1,-1,-1,-1,-1),
-                   "1-4.7.13"=c( 0, 3, 0,-1,-1,-1),
-                 "c-1.4.7.13"=c( 0,-1, 4,-1,-1,-1),
-                       "7-13"=c( 0, 0, 0, 1,-1, 0),
-                     "4-7.13"=c( 0, 0, 0, 1, 1,-2))
-
-clover.lmat <- clover.str.clov.mmc$none$lmat %*% clover.comp
-zapsmall(clover.lmat)[2:7,]
-
-
-clover.str.clov.lmat.mmc <-
-multicomp.mmc(rhiz.clover.aov, focus="strain",
-              adjust=list(comb="clover"),
-              lmat=clover.lmat,
-              method="Tukey",
-              crit.point=qtukey(1-.05/2, 6, 48)/sqrt(2),
-              ry=c(19,38),
-              plot=FALSE)
-clover.str.clov.lmat.mmc <-
-  multicomp.label.change(clover.str.clov.lmat.mmc, "adj1", "clov")
-for (i in 1:3)
-  clover.str.clov.lmat.mmc[[i]]$method <- "Tukey"
-plot(clover.str.clov.lmat.mmc)
-## lmat only, no mca
-## export.eps(h2("mmc/figure/clover.str.clov.lmat.mmc.eps"))
-plotMatchMMC(clover.str.clov.lmat.mmc$lmat, col.signif="blue")
-## tiebreaker not needed, but here it is anyway
-
-
-## simple effects with clover+alfalfa
-clover.str.clovalf.mmc <-
-multicomp.mmc(rhiz.clover.aov, focus="strain",
-              adjust=list(comb="clover+alfalfa"),
-              method="Tukey",
-              crit.point=qtukey(1-.05/2, 6, 48)/sqrt(2),
-              ry=c(19,38),
-              plot=FALSE)
-clover.str.clovalf.mmc <-
-  multicomp.label.change(clover.str.clovalf.mmc, "adj1", "clovalf")
-for (i in 1:2)
-  clover.str.clovalf.mmc[[i]]$method <- "Tukey"
-plot(clover.str.clovalf.mmc)
-## mca only of clover+alfalfa
-## export.eps(h2("mmc/figure/clover.str.clovalf.mmc.eps"))
-plotMatchMMC(clover.str.clovalf.mmc$mca, col.signif="blue")
-## export.eps(h2("mmc/figure/clover.str.clovalf.mca.eps"))
-par(old.omd)
-## identification of significant contrasts not needed because nothing is significant
-})
 
 
 
@@ -639,21 +417,15 @@ par(old.omd)
 data(plasma)
 plasma <- plasma ## local copy
 
-old.par <- if.R(r=par(mfrow=c(2,1)),
-                s=par(mfrow=c(1,2)))
+old.par <- par(mfrow=c(2,1))
 interaction.plot(plasma$id, plasma$time, plasma$plasma, fixed=TRUE, cex=1.3)
 interaction.plot(plasma$time, plasma$id, plasma$plasma, cex=1.3)
 par(old.par)
 ##trellis.device(postscript,file="tway/figure/plasmaint.eps",horizontal=TRUE)
 ## I see anomolies for id=3 at 8pm and for id=6 at 11am.
 
-## if.R(s=
-##      attr(plasma$time, "position") <- c(1,3,5,7,9)+.5
-##      ,r={})
 position(plasma$time) <- c(1,3,5,7,9)+.5
-print(position=
-      if.R(r=c(0,0,.97,1),
-           s=c(0,.05,1,1)),
+print(position=c(0,0,.97,1),
       interaction2wt(plasma ~ time + id, data=plasma,
                      par.strip.text=list(cex=1.4),
                      main.cex=1.6,
@@ -673,36 +445,21 @@ workstation.aov <- aov(devices ~ method / station,
 summary(workstation.aov)
 model.tables(workstation.aov, se=TRUE)
 
-if.R(s=
-     print(position=c(0,.4, 1,1),
-           t(bwplot(station ~ devices | method, data=workstation,
-                    xlab=list(cex=1.4),
-                    ylab=list("station %in% method", cex=1.4),
-                    strip=function(..., strip.names)
-                    strip.default(..., strip.names=c(TRUE, TRUE)),
-                    par.strip.text=list(cex=1.4),
-                    scales=list(x=list(cex=1),y=list(cex=1.2)),
-                    layout=c(3,1)))
-           )
-,r=
-     bwplot(devices ~ station | method, data=workstation,
-            ylab=list(cex=1.4),
-            xlab=list("station %in% method", cex=1.4),
-            strip=function(..., strip.names)
-            strip.default(..., strip.names=c(TRUE, TRUE)),
-            par.strip.text=list(cex=1.4),
-            scales=list(x=list(cex=1),y=list(cex=1.2)),
-            layout=c(3,1))
-     )
+bwplot(devices ~ station | method, data=workstation,
+       ylab=list(cex=1.4),
+       xlab=list("station %in% method", cex=1.4),
+       strip=function(..., strip.names)
+       strip.default(..., strip.names=c(TRUE, TRUE)),
+       par.strip.text=list(cex=1.4),
+       scales=list(x=list(cex=1),y=list(cex=1.2)),
+       layout=c(3,1))
 ## export.eps(hh("tway/figure/workstation.eps"))
 
 
 ## feed.s
 data(feed)
 
-print(position=
-      if.R(r=c(0,0,.96,1),
-           s=c(0,.05,1,1)),
+print(position=c(0,0,.96,1),
       interaction2wt(retained ~ supp + temp, data=feed,
                      ##par.strip.text=list(cex=1.4),
                      main.cex=1.6,
@@ -718,8 +475,7 @@ feed.int.aov <- aov(retained ~ temp * supp, data=feed)
 anova(feed.int.aov)
 model.tables(feed.int.aov, type="means", se=TRUE)
 
-old.par <- if.R(r=par(mfrow=c(2,1)),
-                s=par(mfrow=c(1,2)))
+old.par <- par(mfrow=c(2,1))
 interaction.plot(feed$temp, feed$supp, feed$retained, fixed=TRUE, cex=1.3)
 interaction.plot(feed$supp, feed$temp, feed$retained, fixed=TRUE, cex=1.3)
 par(old.par)
